@@ -53,7 +53,7 @@ bbd.design <- function(nfactors, ncenter=4, factor.names = NULL, default.levels=
           di$type <- "bbd.blocked"
           di <- c(di,blocklist)
           }
-    di <- c(di, list(randomize=randomize, seed=seed, replications=1, repeat.only=FALSE, creator=creator, 
+    di <- c(di, list(randomize=randomize, seed=seed, replications=1, repeat.only=FALSE, ncenter=ncenter, creator=creator, 
         coding=make.formulas(paste("x",1:nfactors,sep=""),factor.names)))
     design.info(design) <- di
     design
